<?php

namespace Modules\Pp\Http\Controllers;

use App\Http\Controllers\ExcelVariable;
use DateInterval;
use DatePeriod;
use DateTime;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Pp\Entities\Machinary;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Color;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

class ProductionPlanReportExportController extends Controller
{
    private static $H_ID = 1;
    private static $V_ID = 1;
    private static $styleBorderArray = [
        'borders' => [
            'allBorders' => [
                'borderStyle' => Border::BORDER_THIN,
                'color' => ['argb' => 'FF000000'],
            ],
        ],
    ];

    public function exportProductionPlanExcel($factory, $machine, $date_from, $date_to)
    {

        ini_set('max_execution_time', '0');  // Set it to 5 minutes, for example

        $date_array = $this->getDateArray($date_from, $date_to);
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $this->reportHeader($sheet, $date_array);
        $array = $this->createProductionPlanReport($factory, $machine, $date_from, $date_to);
        foreach ($array as $row) {
            $this->reportBody($sheet, $row);
        }


        // Save the file
        $writer = new Xlsx($spreadsheet);
        $fileName = 'production_plan_report.xlsx';
        $filePath = storage_path("app/public/{$fileName}");

        $writer->save($filePath);
        // Return the file as a response
        return response()->download($filePath)->deleteFileAfterSend(true);
    }



    private function reportHeader($sheet, $date_array)
    {
        $sheet->setCellValue("A1", "Production Plan Report ");
        $sheet->mergeCells(ExcelVariable::$cell[0] . ProductionPlanReportExportController::$H_ID . ":" . ExcelVariable::$cell[count($date_array)] . ProductionPlanReportExportController::$H_ID);
        $sheet->getStyle("A1")->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle("A1")->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);
        $sheet->getStyle("A1")->getFont()->setBold(true);
    }


    private function reportBody($sheet, $row)
    {

        $machine_name = $row[0]['machine'];
        $day = $row[0]['day'];
        $night = $row[0]['night'];
        $this->reportMachineColumn($sheet, $machine_name);
        $this->reportDayNightColumn($sheet);
        $this->reportDayRow($sheet, $day);
        $this->reportNightRow($sheet, $night);
    }


    private function reportMachineColumn($sheet, $machineName)
    {
        ProductionPlanReportExportController::$V_ID += 2;
        $M_CEL_FROM_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle("A" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle("A" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);
        $sheet->getStyle("A" . ProductionPlanReportExportController::$V_ID)->getFont()->setBold(true);
        $sheet->setCellValue("A" . ProductionPlanReportExportController::$V_ID, $machineName);
        $sheet->mergeCells("A" . ProductionPlanReportExportController::$V_ID . ":" . "A" . (ProductionPlanReportExportController::$V_ID += 13));
        $M_CEL_TO_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle('A' . $M_CEL_FROM_ID . ':A' . $M_CEL_TO_ID)->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
    }


    private function reportDayNightColumn($sheet)
    {
        ProductionPlanReportExportController::$V_ID -= 13;
        $M_CEL_FROM_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getFont()->setBold(true);
        $sheet->setCellValue("B" . ProductionPlanReportExportController::$V_ID, "Day");
        $sheet->mergeCells("B" . ProductionPlanReportExportController::$V_ID . ":" . "B" . (ProductionPlanReportExportController::$V_ID += 6));
        $M_CEL_TO_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle('B' . $M_CEL_FROM_ID . ':B' . $M_CEL_TO_ID)->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);

        ProductionPlanReportExportController::$V_ID += 1;
        $M_CEL_FROM_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER);
        $sheet->getStyle("B" . ProductionPlanReportExportController::$V_ID)->getFont()->setBold(true);
        $sheet->setCellValue("B" . ProductionPlanReportExportController::$V_ID, "Night");
        $sheet->mergeCells("B" . ProductionPlanReportExportController::$V_ID . ":" . "B" . (ProductionPlanReportExportController::$V_ID += 6));
        $M_CEL_TO_ID = ProductionPlanReportExportController::$V_ID;
        $sheet->getStyle('B' . $M_CEL_FROM_ID . ':B' . $M_CEL_TO_ID)->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
    }


    private function reportDayRow($sheet, $day)
    {


        /** Date */
        ProductionPlanReportExportController::$V_ID -= 13;
        ProductionPlanReportExportController::$H_ID = 1;
        $date = $day["date"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Date");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($date as $dt) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $dt);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 13;


        /** po */
        ProductionPlanReportExportController::$V_ID -= 12;
        ProductionPlanReportExportController::$H_ID = 1;
        $po = $day["po"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "PO");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($po as $p) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $p);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 12;



        /** Size */
        ProductionPlanReportExportController::$V_ID -= 11;
        ProductionPlanReportExportController::$H_ID = 1;
        $size = $day["size"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Size");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($size as $siz) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $siz);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 11;


        /** Quantity */
        ProductionPlanReportExportController::$V_ID -= 10;
        ProductionPlanReportExportController::$H_ID = 1;
        $plan_qty = $day["plan_qty"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Plan Qty");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($plan_qty as $qty) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_RIGHT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $qty);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 10;



        /** Farm */
        ProductionPlanReportExportController::$V_ID -= 9;
        ProductionPlanReportExportController::$H_ID = 1;
        $farm = $day["farm"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Farm");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($farm as $frm) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $frm);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 9;



        /** Country */
        ProductionPlanReportExportController::$V_ID -= 8;
        ProductionPlanReportExportController::$H_ID = 1;
        $country = $day["country"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Country");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($country as $crty) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $crty);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 8;



        /** Other */
        ProductionPlanReportExportController::$V_ID -= 7;
        ProductionPlanReportExportController::$H_ID = 1;
        $other = $day["other"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Other");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($other as $othr) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $othr);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 7;
    }



    private function reportNightRow($sheet, $night)
    {

        /** Date */
        ProductionPlanReportExportController::$V_ID -= 6;
        ProductionPlanReportExportController::$H_ID = 1;
        $date = $night["date"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Date");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($date as $dt) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $dt);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 6;


        /** po */
        ProductionPlanReportExportController::$V_ID -= 5;
        ProductionPlanReportExportController::$H_ID = 1;
        $po = $night["po"];
        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "PO");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($po as $p) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $p);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 5;


        /** size */
        ProductionPlanReportExportController::$V_ID -= 4;
        ProductionPlanReportExportController::$H_ID = 1;
        $size = $night["size"];

        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Size");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($size as $sz) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $sz);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 4;



        /** Plan Quantity */
        ProductionPlanReportExportController::$V_ID -= 3;
        ProductionPlanReportExportController::$H_ID = 1;
        $plan_qty = $night["plan_qty"];

        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Plan Qty");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($plan_qty as $sz) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $sz);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 3;



        /** Farm */
        ProductionPlanReportExportController::$V_ID -= 2;
        ProductionPlanReportExportController::$H_ID = 1;
        $farm = $night["farm"];

        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Farm");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($farm as $sz) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $sz);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 2;


        /** Country */
        ProductionPlanReportExportController::$V_ID -= 1;
        ProductionPlanReportExportController::$H_ID = 1;
        $country = $night["country"];

        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Country");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($country as $sz) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $sz);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 1;


        /** Other */
        ProductionPlanReportExportController::$V_ID -= 0;
        ProductionPlanReportExportController::$H_ID = 1;
        $other = $night["other"];

        ProductionPlanReportExportController::$H_ID += 1;
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
        $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), "Other");
        $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        foreach ($other as $oth) {
            ProductionPlanReportExportController::$H_ID += 1;
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID])->getAlignment()->setHorizontal(Alignment::HORIZONTAL_LEFT);
            $sheet->setCellValue(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID), $oth);
            $sheet->getStyle(ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID) . ':' . ExcelVariable::$cell[ProductionPlanReportExportController::$H_ID] . (ProductionPlanReportExportController::$V_ID))->applyFromArray(ProductionPlanReportExportController::$styleBorderArray);
        }
        ProductionPlanReportExportController::$V_ID += 0;
    }




    private function getDateArray($date_from, $date_to)
    {

        $date_query = "SELECT LAST_DAY('" . $date_to . "') AS end_date";
        $date_to = DB::select($date_query)[0]->end_date;


        $date_array = [];
        $startDate = new DateTime($date_from);
        $endDate = new DateTime($date_to);
        $endDate->modify('+1 day'); // Include the end date in the loop

        $interval = new DateInterval('P1D'); // 1 day interval
        $dateRange = new DatePeriod($startDate, $interval, $endDate);

        foreach ($dateRange as $date) {
            $date_array[] = $date->format('d-M');
        }

        return $date_array;
    }



    private function getDateArray2($date_from, $date_to)
    {

        $date_query = "SELECT LAST_DAY('" . $date_to . "') AS end_date";
        $date_to = DB::select($date_query)[0]->end_date;


        $date_array = [];
        $startDate = new DateTime($date_from);
        $endDate = new DateTime($date_to);
        $endDate->modify('+1 day'); // Include the end date in the loop

        $interval = new DateInterval('P1D'); // 1 day interval
        $dateRange = new DatePeriod($startDate, $interval, $endDate);

        foreach ($dateRange as $date) {
            $date_array[] = $date->format('Y-m-d');
        }
        return $date_array;
    }



    public function createProductionPlanReport($factory, $machine, $date_from, $date_to)
    {
        $factory_id = $factory;
        $machinery_result = Machinary::where([['factory_id', '=', $factory], ['status', '=', '1']])->get();
        $machinery_id_array = [];
        foreach ($machinery_result as $mach) {
            array_push($machinery_id_array, $mach->machinery_id);
        }

        $factory_ = Machinary::where('factory_id', '=', $factory)->first();
        if ($factory_) {
            $factory = $factory_->site_id;
        }


        $factory_filter = "";
        if ($factory != "null") {
            $factory_filter = " AND pp_machinery.site_id  = '" . $factory . "' ";
            //$machinery_result = Machinary::where([['site_id', '=', $factory], ['status', '=', '1']])->get();
        }



        $machine_filter = "";
        if ($machine != "null") {
            $machine_filter = " AND pp_machinery_plans.machinery_id = '" . $machine . "' ";
            $machinery_result = Machinary::where([['machinery_id', '=', $machine], ['status', '=', '1']])->get();
        } else {
            $machine_filter = " AND pp_machinery_plans.machinery_id in ('" . implode("','", $machinery_id_array) . "')";
        }

        $query = 'SELECT DISTINCT pp_machinery.machinery_no,
        pp_machinery.machinery_id,
        pp_customer_orders.factory_po_num,
        pp_machinery_plans.date,
        st_products.size,
        pp_machinery_plans.quantity,
        "" AS farm,
        st_countries.country_name,
        "" AS other,
        hr_att_shifts.remark AS shift FROM pp_machinery_plans
        INNER JOIN hr_att_shifts ON pp_machinery_plans.shift_id = hr_att_shifts.shift_id
        INNER JOIN pp_customer_order_plans_data ON pp_machinery_plans.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
        INNER JOIN pp_customer_order_plans ON pp_customer_order_plans_data.customer_order_plan_id = pp_customer_order_plans.customer_order_plan_id
        INNER JOIN pp_customer_orders ON pp_customer_order_plans.order_id = pp_customer_orders.order_id
        LEFT JOIN st_products ON pp_customer_order_plans_data.product_id = st_products.product_id
        INNER JOIN st_countries ON pp_customer_orders.country_id = st_countries.country_id
        INNER JOIN pp_machinery ON pp_machinery_plans.machinery_id = pp_machinery.machinery_id
        WHERE pp_machinery_plans.date BETWEEN "' . $date_from . '" AND "' . $date_to . '" ' . $machine_filter . ' ' . $factory_filter . ' ORDER BY pp_machinery_plans.date';

        $date_query = "SELECT LAST_DAY('" . $date_to . "') AS end_date";
        $date_to = DB::select($date_query)[0]->end_date;


        $date_array = [];
        $date_array2 = [];
        $startDate = new DateTime($date_from);
        $endDate = new DateTime($date_to);
        $endDate->modify('+1 day'); // Include the end date in the loop

        $interval = new DateInterval('P1D'); // 1 day interval
        $dateRange = new DatePeriod($startDate, $interval, $endDate);

        foreach ($dateRange as $date) {
            $date_array[] = $date->format('d-M');
            $date_array2[] = $date->format('Y-m-d');
        }



        $result = DB::select($query);
        $plan_array = [];
        foreach ($date_array2 as $date) {
            if (isset($result[0])) {
                $res_copy = clone $result[0];
                //$res_copy->machinery_no = "";
                //$res_copy->machinery_id = "";
                $res_copy->quantity = 0;
                $res_copy->factory_po_num = "";
                $res_copy->size = "";
                $res_copy->farm = "";
                $res_copy->other = "";
                $res_copy->country_name = "";
                $res_copy->date = $date;
                $res_copy->shift = "day";
                $plan_array[] =  $res_copy;
            }
            if (isset($result[0])) {
                $res_copy = clone $result[0];
                //$res_copy->machinery_no = "";
                //$res_copy->machinery_id = "";
                $res_copy->quantity = 0;
                $res_copy->factory_po_num = "";
                $res_copy->size = "";
                $res_copy->farm = "";
                $res_copy->other = "";
                $res_copy->country_name = "";
                $res_copy->date = $date;
                $res_copy->shift = "night";
                $plan_array[] =  $res_copy;
            }
        }


        foreach ($result as $res) {
            foreach ($plan_array as $plan) {
                if ($res->date == $plan->date && $plan->machinery_id == $res->machinery_id) {
                    $plan->machinery_no = $res->machinery_no;
                    $plan->machinery_id = $res->machinery_id;
                    $plan->factory_po_num = $res->factory_po_num;
                    $plan->size = $res->size;
                    $plan->farm = $res->farm;
                    $plan->quantity = $res->quantity;
                    $plan->other = $res->other;
                    $plan->country_name = $res->country_name;
                    $plan->shift = $res->shift;
                    $plan->date = $res->date;
                    break;
                }
            }
        }




        //dd($plan_array);



        $machinery_array = [];


        foreach ($machinery_result as $machine_res) {

            $day_po_array = [];
            $day_size_array = [];
            $day_plan_array = [];
            $day_farm_array = [];
            $day_country_array = [];
            $day_other_array = [];

            $night_po_array = [];
            $night_size_array = [];
            $night_plan_array = [];
            $night_farm_array = [];
            $night_country_array = [];
            $night_other_array = [];

            foreach ($plan_array as $data) {
                if ( $data->shift == "day") {
                    $day_po_array[] = $data->factory_po_num;
                    $day_size_array[] = $data->size;
                    $day_plan_array[] = $data->quantity;
                    $day_farm_array[] = $data->farm;
                    $day_country_array[] = $data->country_name;
                    $day_other_array[] = $data->other;
                }
                if ( $data->shift == "night") {
                    $night_po_array[] = $data->factory_po_num;
                    $night_size_array[] = $data->size;
                    $night_plan_array[] = $data->quantity;
                    $night_farm_array[] = $data->farm;
                    $night_country_array[] = $data->country_name;
                    $night_other_array[] = $data->other;
                }
            }



            $machinery_array[] = [
                "machine" => $machine_res->machinery_no,
                "day" => [
                    "date" => $date_array,
                    "po" => $day_po_array,
                    "size" => $day_size_array,
                    "plan_qty" => $day_plan_array,
                    "farm" => $day_farm_array,
                    "country" => $day_country_array,
                    "other" => $day_other_array,
                ],
                "night" => [
                    "date" => $date_array,
                    "po" => $night_po_array,
                    "size" => $night_size_array,
                    "plan_qty" => $night_plan_array,
                    "farm" => $night_farm_array,
                    "country" => $night_country_array,
                    "other" => $night_other_array,
                ]
            ];
        }


        $title = "Production Plan Report";
        $machineries = [];
        foreach ($machinery_array as $machinery) {
            $machine = [];
            array_push($machine, $machinery);
            array_push($machineries, $machine);
        }
        return $machineries;
    }
}
