<?php

namespace Modules\Pp\Http\Controllers;

use App\Http\Controllers\OrderStatusHistoryController;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Arr;
use Modules\Pp\Entities\PurchaseOrder;
use Modules\Pp\Entities\CustomerPlan;
use Modules\Pp\Entities\CustomerPlanData;
use Modules\Pp\Entities\Product;
use Illuminate\Support\Facades\DB;
use Modules\Pd\Entities\ScheduleCustomerOrderPlan;
use Modules\Pd\Entities\ScheduleMachineryPlan;
use Modules\Pd\Entities\ScheduleOrderResourceBom;
use Modules\Pd\Entities\ScheduleOrderResourceHr;
use Modules\Pp\Entities\CustomerOrder;
use Modules\Pp\Entities\CustomerOrderData;
use Modules\St\Entities\Customer;

class SupplyPlanController extends Controller
{
    // functions by nipuna start
    public function addorderPurchaceOrder()
    {
        try {
            $allOrders = DB::select("SELECT *FROM pp_customer_orders WHERE  pp_customer_orders.production_status = '0' AND (pp_customer_orders.order_status = '1' || pp_customer_orders.order_status = '4')");
            $responseBody = $this->responseBody(true, "CustomerPlan", "all", $allOrders);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlan", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    // do this tomorrow
    public function orderQuantity($productCodeID)
    {
        try {
            $orderQuentity = 0;

            $customerOrder = CustomerOrderData::where('order_data_id', $productCodeID)->first();
            if ($customerOrder) {
                $orderQuentity = $customerOrder->quantity_pieces;
            }
            $responseBody = $this->responseBody(true, "CustomerPlan", "checkQuantity", $orderQuentity);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlan", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function orderPlanQuantity($orderDataID)
    {
        try {
            $planQuantity = 0;
            $planQuantity = CustomerPlanData::where('order_data_id', $orderDataID)->select(DB::raw('SUM(quantity) as quantity'))->first();
            $responseBody = $this->responseBody(true, "CustomerPlan", "planQuantity", $planQuantity);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlan", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    // functions by nipuna end

    /**
     * PurchaseOrder
     * This function is used to search purchase order from order id.
     * @return Json This returns as response.
     */

    //modified by nipuna
    public function productToPurchaseOrder($id)
    {
        try {
            $purchaseOrder = DB::select("SELECT * from pp_customer_orders_data WHERE order_id = " . $id);
            $purchaseOrder = DB::table('pp_customer_orders_data')
                ->join('pp_customer_orders', 'pp_customer_orders_data.order_id', '=', 'pp_customer_orders.order_id')
                ->where('pp_customer_orders_data.order_id', $id)
                ->select('pp_customer_orders_data.*', 'pp_customer_orders.factory_po_num')
                ->get();
            $responseBody = $this->responseBody(true, "productToPurchaseOrder", "found", $purchaseOrder);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "productToPurchaseOrder", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    //function by nipuna start
    public function productQuantity($id)
    {
        try {
            $purchaseOrder = DB::select("SELECT quantity_pieces from pp_customer_orders_data WHERE order_data_id = " . $id);
            $responseBody = $this->responseBody(true, "productQuantity", "found", $purchaseOrder);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "productQuantity", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    //function by nipuna end





    public function getQuantity($id)
    {
        try {
            $customerOrder = CustomerOrderData::find($id);
            $quantity = 0;
            if ($customerOrder) {
                $quantity = $customerOrder->quantity_pieces;
            }
            $responseBody = $this->responseBody(true, "getQuantity", "found", $quantity);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "getQuantity", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * settings
     * This function is used to search settings records from the database.
     * @return Json This returns as response.
     */
    public function settings()
    {

        try {

            $purchaseOrder = PurchaseOrder::where('status', '=', 0)->get();
            $result = [
                "PurchaseOrder" => $purchaseOrder,
            ];
            $responseBody = $this->responseBody(true, "Settings", "all", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }


    /**
     * save
     * This function is used to save new Customer Order to database.
     * @param request This is the paramter to save function
     * @return Json This returns as response.
     */
    public function save(Request $request)
    {

        try {

            $customerPlan = new CustomerPlan();
            $customerPlan->order_id = $request->get('selcPurchaseOrder');
            $customerPlan->manufacturing_order_number = $request->get('inpManuOrderNum');
            $customerPlan->trans_date = $request->get('dteDate');
            $customerPlan->from_date = $request->get('dteFromDate');
            $customerPlan->to_date = $request->get('dteToDate');
            $customerPlan->description = $request->get('txtDescription');
            $save = $customerPlan->save();

            if ($save) {
                $order = CustomerOrder::find($customerPlan->order_id);
                if ($order) {
                    $order->production_status = 1;
                    $order->update();
                }
                $responseBody = $this->responseBody(true, "CustomerPlan", "saved", $customerPlan);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    /**
     * saveData
     * This function is used to save new customer order data to database.
     * @param request This is the paramter to save function
     * @return Json This returns as response.
     */
    public function saveData(Request $request)
    {

        try {

            $customerPlanData = new CustomerPlanData();
            $customerPlanData->customer_order_plan_id = $request->get('txtOrderId');
            $customerPlanData->start_date = $request->get('dteStartDate');
            $customerPlanData->end_date = $request->get('dteEndDate');
            $customerPlanData->product_id = $request->get('txtProductID');
            $customerPlanData->product_name = $request->get('txtProductName');
            $customerPlanData->quantity = $request->get('txtQuantity');
            $customerPlanData->status = true;
            $save = $customerPlanData->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "saved", $customerPlanData);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * allOrderPlan
     * This function is used to search all customer order records from the database.
     * @return Json This returns as response.
     */
    public function allOrderPlan()
    {

        try {
            $query = "SELECT pp_customer_orders.purchase_order,pp_customer_orders.delivery_date, pp_customer_order_plans.* FROM pp_customer_order_plans
            INNER JOIN pp_customer_orders ON pp_customer_order_plans.order_id = pp_customer_orders.order_id WHERE  pp_customer_orders.production_status < 2";
            $customerPlan = DB::select($query);

            /* $customerPlanArray = array();
            foreach ($customerPlan as $data) {
                $schedule = ScheduleCustomerOrderPlan::where('customer_order_plan_id', '=', $data->customer_order_plan_id)->first();
                if (!$schedule) {
                    array_push($customerPlanArray, $data);
                }
            }*/
            $responseBody = $this->responseBody(true, "CustomerPlan", "all", $customerPlan);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    /**
     * allOrderPlanData
     * This function is used to search all customer order data records from the database.
     * @return Json This returns as response.
     */
    public function allOrderPlanData($id)
    {

        try {
            //$customerPlanData = CustomerPlanData::find($id);
            $customerPlanData =  CustomerPlanData::where('customer_order_plan_id', $id)->get();
            $responseBody = $this->responseBody(true, "CustomerPlanData", "all", $customerPlanData);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    /**
     * deleteOrder
     * This function is used to delete customer order from customer order id.
     * @return Json This returns as response.
     */
    public function deleteOrder($id)
    {
        try {
            $planData = CustomerPlanData::where('customer_order_plan_id', '=', $id)->first();
            if ($planData) {
                $responseBody = $this->responseBody(true, "CustomerPlan", "deleteOrder", ["message" => "warning", "order" => $planData->manufacturing_order_no]);
            } else {
                $customerPlan = CustomerPlan::find($id);
                $delete = $customerPlan->delete();
                if ($delete) {
                    $responseBody = $this->responseBody(true, "CustomerPlan", "deleteOrder", ["message" => "success"]);
                }
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * deleteProductToOrder
     * This function is used to delete customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function deleteProductToOrder($id)
    {
        try {
            $machineryPlan = ScheduleMachineryPlan::where('customer_order_plan_data_id', '=', $id)->first();
            if ($machineryPlan) {
                $responseBody = $this->responseBody(true, "MachineryPlan", "deleteProductToOrder", ["message" => "warning", "msg" => "Already allocated to machinery plan"]);
            }
            $hrPlan = ScheduleOrderResourceHr::where('customer_order_plan_data_id', '=', $id)->first();
            if ($hrPlan) {
                $responseBody = $this->responseBody(true, "HrPlan", "deleteProductToOrder", ["message" => "warning", "msg" => "Already allocated to HR plan"]);
            }
            $bomPlan = ScheduleOrderResourceBom::where('customer_order_plan_data_id', '=', $id)->first();
            if ($bomPlan) {
                $responseBody = $this->responseBody(true, "BomPlan", "deleteProductToOrder", ["message" => "warning", "msg" => "Already allocated to BOM plan"]);
            }

            if (!$machineryPlan && !$hrPlan && !$bomPlan) {
                $customerPlanData = CustomerPlanData::find($id);
                $deleteData = $customerPlanData->delete();
                if ($deleteData) {
                    $responseBody = $this->responseBody(true, "CustomerPlanData", "deleted", $customerPlanData);
                }
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * customerPlan
     * This function is used to search customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function customerPlan($id)
    {

        try {
            $customerPlan = CustomerPlan::where('customer_order_plan_id', $id)->first();
            $order_id = $customerPlan->order_id;
            $purchase_order = DB::table('pp_customer_orders')->where('order_id', '=', $order_id)->first();

            $settings = [
                "purchase_order" => $purchase_order->purchase_order,
            ];

            $responseBody = $this->responseBody(true, "CustomerPlan", "all", ["customerPlan" => $customerPlan, "settings" => $settings]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception->getmessage());
        }
        return response()->json(["data" => $responseBody]);
    }

    /**
     * customerPlanData
     * This function is used to search customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function customerPlanData($id)
    {

        try {
            $customerPlanData = CustomerPlanData::find($id);



            $responseBody = $this->responseBody(true, "CustomerPlanData", "all", ["customerPlanData" => $customerPlanData]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * updatePlan
     * This function is used to update customer order plan.
     * @param request This is the paramter to update function
     * @return Json This returns as response.
     */
    public function updatePlan(Request $request)
    {

        try {

            $id = $request->get('hidOrderID');
            $customerPlan = CustomerPlan::find($id);
            $customerPlan->order_id = $request->get('selcPurchaseOrder');
            //$customerPlan->order_data_id=$request->get("hidProduct");
            $customerPlan->manufacturing_order_number = $request->get('inpManuOrderNum');
            $customerPlan->trans_date = $request->get('dteDate');
            $customerPlan->from_date = $request->get('dteFromDate');
            $customerPlan->to_date = $request->get('dteToDate');
            $customerPlan->description = $request->get('txtDescription');
            $save = $customerPlan->update();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlan", "updated",  $customerPlan);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", $customerPlan, $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * updatePlanData
     * This function is used to update customer order plan data.
     * @param request This is the paramter to update function
     * @return Json This returns as response.
     */
    public function updatePlanData(Request $request)
    {

        try {

            $id = $request->get('hidOrderPlanID');
            $customerPlanData = CustomerPlanData::find($id);
            $customerPlanData->customer_order_plan_id = $request->get('txtOrderId');
            $customerPlanData->start_date = $request->get('dteStartDate');
            $customerPlanData->end_date = $request->get('dteEndDate');
            $customerPlanData->product_id = $request->get('txtProductID');
            $customerPlanData->product_name = $request->get('txtProductName');
            $customerPlanData->quantity = $request->get('txtQuantity');
            $save = $customerPlanData->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updated", "");
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", $customerPlanData, $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * searchName
     * This function is used to search employee name from product id.
     * @return Json This returns as response.
     */
    public function searchPName()
    {
        $data = Product::where('product_type_id', '=', 4)->get();
        $nameAray = [];
        for ($j = 0; $j < count($data); $j++) {
            array_push($nameAray, [
                "img" => "",
                "id" => $data[$j]['product_primary_id'],
                "value" => $data[$j]['product_name']."-".$data[$j]['product_id'],
            ]);
        }
        $idAray = [];
        for ($j = 0; $j < count($data); $j++) {
            array_push($idAray, [
                "img" => "",
                "id" => $data[$j]['product_primary_id'],
                "value" => $data[$j]['product_id'],
            ]);
        }
        return response()->json(["name" => $nameAray, "id" => $idAray]);
    }


    public function getPName($product_id)
    {
        $data = Product::find($product_id);
        return response()->json($data);
    }


    /**
     * disableCustomerPlanData
     * This function is used to disable customer order plan data records.
     * @param request This is the paramter to disableCustomerPlanData function
     * @param id This is the paramter for identify update record.
     */
    public function disableCustomerPlanData(Request $request, $id)
    {
        try {

            $value = $request->get('status');

            $object = CustomerPlanData::find($id);
            $object->status = $value;
            $update = $object->save();
            if ($update) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updated", null);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function loadProductCode($orderID)
    {
        try {
            $query = "SELECT pp_customer_orders_data.order_data_id, CONCAT(pp_customer_orders_data.product_code,'  -  (',pp_product_mixes.product_mix,')') AS product_name
            FROM pp_customer_orders_data INNER JOIN pp_product_mixes ON pp_customer_orders_data.product_mix_id = pp_product_mixes.product_mix_id   WHERE pp_customer_orders_data.order_id = '" . $orderID . "' ";

            $result = DB::select($query);
            $responseBody = $this->responseBody(true, "CustomerPlanData", "allProduct", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function saveAddProductToOrder(Request $request)
    {
        try {

            $order_id = $request->get('order_id');
            $customerOrderPlanID = $request->get('customerOrderPlanID');
            $manufacturingOrderNo = $request->get('manufacturingOrderNo');
            $manufacturingOrderConcatNo = $request->get('manufacturingOrderConcatNo');
            $productCode_orderDataID = $request->get('productCode');
            $productID = $request->get('product_primary_id');
            $productName = $request->get('txtProductName');
            $startDate = $request->get('dteStartDate');
            $endDate = $request->get('dteEndDate');
            $quantity = $request->get('txtQuantity');

            if ($manufacturingOrderConcatNo != null) {
                $manufacturingOrderNo = $manufacturingOrderNo . $manufacturingOrderConcatNo;
            } else {
                $manufacturingOrderNo = explode("-", $manufacturingOrderNo)[0];
            }

            $customerPlanData = new  CustomerPlanData();
            $customerPlanData->customer_order_plan_id = $customerOrderPlanID;
            $customerPlanData->order_data_id = $productCode_orderDataID;
            $customerPlanData->manufacturing_order_no = $manufacturingOrderNo;
            //$customerPlanData->start_date = $startDate;
            //$customerPlanData->end_date = $endDate;
            $customerPlanData->product_id = $productID;
            $customerPlanData->product_name = $productName;
            $customerPlanData->quantity = $quantity;
            $customerPlanData->status = true;
            $customerPlanData->production_schedule = false;
            $customerPlanData->production_status = 1;
            if ($customerPlanData->save()) {
                OrderStatusHistoryController::changeProductionStatus($customerPlanData);
                $customer_orders_data = CustomerOrderData::where('order_id', '=', $order_id)->get();
                $production_status = '1';
                foreach ($customer_orders_data as $order_data) {
                    $plan_data = CustomerPlanData::where('order_data_id', '=', $order_data->order_data_id)->first();
                    if (!$plan_data) {
                        $production_status = '0';
                        break;
                    }
                }
                $customer_order = CustomerOrder::find($order_id);
                if ($customer_order) {
                    $customer_order->production_status = $production_status;
                    $customer_order->update();
                }
                
                $responseBody = $this->responseBody(true, "CustomerPlanData", "saveAddProductToOrder", $customerPlanData);
            } else {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "saveAddProductToOrder", false);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }




    public function getProductToOrder($id)
    {
        try {

            $planData = CustomerPlanData::find($id);
            $planData->manufacturing_order_concat_no = '';
            if (count(explode("-", $planData->manufacturing_order_no)) > 1) {
                $planData->manufacturing_order_concat_no = explode("-", $planData->manufacturing_order_no)[1];
                $planData->manufacturing_order_no = explode("-", $planData->manufacturing_order_no)[0];
            }
            $responseBody = $this->responseBody(true, "CustomerPlanData", "getProductToOrder", $planData);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }


    public function updateAddProductToOrder(Request $request, $id)
    {
        try {
            $customerOrderPlanID = $request->get('customerOrderPlanID');
            $manufacturingOrderNo = $request->get('manufacturingOrderNo');
            $manufacturingOrderConcatNo = $request->get('manufacturingOrderConcatNo');
            $productCode_orderDataID = $request->get('productCode');
            $productID = $request->get('product_primary_id');
            $productName = $request->get('txtProductName');
            $startDate = $request->get('dteStartDate');
            $endDate = $request->get('dteEndDate');
            $quantity = $request->get('txtQuantity');

            if ($manufacturingOrderConcatNo != null) {
                $manufacturingOrderNo = $manufacturingOrderNo . $manufacturingOrderConcatNo;
            } else {
                $manufacturingOrderNo = explode("-", $manufacturingOrderNo)[0];
            }

            $customerPlanData = CustomerPlanData::find($id);
            $customerPlanData->customer_order_plan_id = $customerOrderPlanID;
            $customerPlanData->order_data_id = $productCode_orderDataID;
            $customerPlanData->manufacturing_order_no = $manufacturingOrderNo;
            //$customerPlanData->start_date = $startDate;
            //$customerPlanData->end_date = $endDate;
            $customerPlanData->product_id = $productID;
            $customerPlanData->product_name = $productName;
            $customerPlanData->quantity = $quantity;
            $customerPlanData->status = true;
            if ($customerPlanData->update()) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updateAddProductToOrder", true);
            } else {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updateAddProductToOrder", false);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function getOrder($id)
    {
        try {

            $orderData = CustomerPlan::find($id);
            $responseBody = $this->responseBody(true, "CustomerPlanData", "getOrder", $orderData);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }




    public function updateOrder(Request $request, $id)
    {
        try {
            $customerPlan =  CustomerPlan::find($id);
            $customerPlan->order_id = $request->get('selcPurchaseOrder');
            $customerPlan->manufacturing_order_number = $request->get('inpManuOrderNum');
            $customerPlan->trans_date = $request->get('dteDate');
            $customerPlan->from_date = $request->get('dteFromDate');
            $customerPlan->to_date = $request->get('dteToDate');
            $customerPlan->description = $request->get('txtDescription');
            if ($customerPlan->update()) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updateOrder", true);
            } else {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updateOrder", false);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function isManufacturingOrderNo($id)
    {
        try {

            $orderData = CustomerPlan::where('manufacturing_order_number', '=', $id)->first();
            if ($orderData) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "isManufacturingOrderNo", true);
            } else {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "isManufacturingOrderNo", false);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function getFactoryPO($id)
    {
        try {
            $order = CustomerOrder::find($id);
            $responseBody = $this->responseBody(true, "CustomerPlanData", "getFactoryPO", $order->factory_po_num);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "getFactoryPO", null);
        }
        return response()->json(["data" => $responseBody]);
    }




    public function isAddProductToOrder($order_id, $product_id)
    {
        try {

            $orderData = CustomerPlanData::where([['customer_order_plan_id', '=', $order_id], ['order_data_id', '=', $product_id]])->first();
            if ($orderData) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "isAddProductToOrder", true);
            } else {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "isAddProductToOrder", false);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
}
